@@ -1,6 +1,6 @@
 covWarton <- function(S, gamma) {
     if (gamma < 0 || gamma > 1) {
-        stop('"gamma" must be within 0 and 1')
+        stop("\"gamma\" must be between 0 and 1")
     }
     ns <- ncol(S)
     D1 <- diag(diag(S)^-0.5)
